==> openshift-model-miscellaneous-6.7.2-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/HardwareSystemVendorBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class HardwareSystemVendorBuilder extends HardwareSystemVendorFluentImpl<HardwareSystemVendorBuilder> implements VisitableBuilder<HardwareSystemVendor,HardwareSystemVendorBuilder>{
  public HardwareSystemVendorBuilder() {
    this(false);
  }
  public HardwareSystemVendorBuilder(Boolean validationEnabled) {
    this(new HardwareSystemVendor(), validationEnabled);
  }
  public HardwareSystemVendorBuilder(HardwareSystemVendorFluent<?> fluent) {
    this(fluent, false);
  }
  public HardwareSystemVendorBuilder(HardwareSystemVendorFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new HardwareSystemVendor(), validationEnabled);
  }
  public HardwareSystemVendorBuilder(HardwareSystemVendorFluent<?> fluent,HardwareSystemVendor instance) {
    this(fluent, instance, false);
  }
  public HardwareSystemVendorBuilder(HardwareSystemVendorFluent<?> fluent,HardwareSystemVendor instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withManufacturer(instance.getManufacturer());
      fluent.withProductName(instance.getProductName());
      fluent.withSerialNumber(instance.getSerialNumber());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public HardwareSystemVendorBuilder(HardwareSystemVendor instance) {
    this(instance,false);
  }
  public HardwareSystemVendorBuilder(HardwareSystemVendor instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withManufacturer(instance.getManufacturer());
      this.withProductName(instance.getProductName());
      this.withSerialNumber(instance.getSerialNumber());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  HardwareSystemVendorFluent<?> fluent;
  Boolean validationEnabled;
  public HardwareSystemVendor build() {
    HardwareSystemVendor buildable = new HardwareSystemVendor(fluent.getManufacturer(),fluent.getProductName(),fluent.getSerialNumber());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-miscellaneous-6.8.0-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/HardwareSystemVendorBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class HardwareSystemVendorBuilder extends HardwareSystemVendorFluent<HardwareSystemVendorBuilder> implements VisitableBuilder<HardwareSystemVendor,HardwareSystemVendorBuilder>{
  public HardwareSystemVendorBuilder() {
    this(false);
  }
  public HardwareSystemVendorBuilder(Boolean validationEnabled) {
    this(new HardwareSystemVendor(), validationEnabled);
  }
  public HardwareSystemVendorBuilder(HardwareSystemVendorFluent<?> fluent) {
    this(fluent, false);
  }
  public HardwareSystemVendorBuilder(HardwareSystemVendorFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new HardwareSystemVendor(), validationEnabled);
  }
  public HardwareSystemVendorBuilder(HardwareSystemVendorFluent<?> fluent,HardwareSystemVendor instance) {
    this(fluent, instance, false);
  }
  public HardwareSystemVendorBuilder(HardwareSystemVendorFluent<?> fluent,HardwareSystemVendor instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new HardwareSystemVendor());

    if (instance != null) {
      fluent.withManufacturer(instance.getManufacturer());
      fluent.withProductName(instance.getProductName());
      fluent.withSerialNumber(instance.getSerialNumber());
      fluent.withManufacturer(instance.getManufacturer());
      fluent.withProductName(instance.getProductName());
      fluent.withSerialNumber(instance.getSerialNumber());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public HardwareSystemVendorBuilder(HardwareSystemVendor instance) {
    this(instance,false);
  }
  public HardwareSystemVendorBuilder(HardwareSystemVendor instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new HardwareSystemVendor());

    if (instance != null) {
      this.withManufacturer(instance.getManufacturer());
      this.withProductName(instance.getProductName());
      this.withSerialNumber(instance.getSerialNumber());
      this.withManufacturer(instance.getManufacturer());
      this.withProductName(instance.getProductName());
      this.withSerialNumber(instance.getSerialNumber());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  HardwareSystemVendorFluent<?> fluent;
  Boolean validationEnabled;
  public HardwareSystemVendor build() {
    HardwareSystemVendor buildable = new HardwareSystemVendor(fluent.getManufacturer(),fluent.getProductName(),fluent.getSerialNumber());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
